==> download.php?d=bsmyjspace_pack_2.6.0_PACK.zip: admin/views/edit/view.html.php <==
<?php
/**
* @version $Id: view.html.php $
* @version		2.5.5 10/11/2015
* @package		com_myjspace
* @author       Bernard Saulmé
* @copyright	Copyright (C) 2010-2011-2012-2013-2014-2015 Bernard Saulmé
* @license      GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
*/

// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die;
if (!defined('DS')) define('DS', DIRECTORY_SEPARATOR);

require_once JPATH_COMPONENT_SITE.DS.'helpers'.DS.'legacy.php';

jimport('joomla.application.component.view');
jimport('joomla.html.parameter');

class MyjspaceViewEdit extends JViewLegacy
{
	function display($tpl = null)
	{
		// Config
		$pparams = JComponentHelper::getParams('com_myjspace');

		// Tags buttons
		$e_name = JRequest::getVar('e_name', 'mjs_editable');
		$allow_tag_myjsp_iframe = $pparams->get('allow_tag_myjsp_iframe', 1);
		$allow_tag_myjsp_include = $pparams->get('allow_tag_myjsp_include', 1);
		$share_page = $pparams->get('share_page', 0);
		$language_filter = $pparams->get('language_filter', 0);
		$show_tags = version_compare(JVERSION, '3.1.4', 'ge') ? $pparams->get('show_tags', 0) : $pparams->get('show_tags', 0);

		// Pagebreak
		$eName = JRequest::getVar('eName', 'mjs_content');

		$this->assignRef('e_name', $e_name);
		$this->assignRef('eName', $eName);
		$this->assignRef('allow_tag_myjsp_iframe', $allow_tag_myjsp_iframe);
		$this->assignRef('allow_tag_myjsp_include', $allow_tag_myjsp_include);
		$this->assignRef('share_page', $share_page);
		$this->assignRef('language_filter', $language_filter);
		$this->assignRef('show_tags', $show_tags);

		parent::display($tpl);
	}
}

?>

==> download.php?d=bsmyjspace_pack_2.6.10_PACK.zip: admin/views/edit/view.html.php <==
<?php
/**
* @version $Id: view.html.php $
* @version		2.6.3 25/07/2018
* @package		com_myjspace
* @author       Bernard Saulmé
* @copyright	Copyright (C) 2010-2011-2012-2013-2014-2015-2016-2017-2018 Bernard Saulmé
* @license      GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
*/

// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die;
if (!defined('DS')) define('DS', DIRECTORY_SEPARATOR);

require_once JPATH_COMPONENT_SITE.DS.'helpers'.DS.'legacy.php';

jimport('joomla.application.component.view');
jimport('joomla.html.parameter');

class MyjspaceViewEdit extends JViewLegacy
{
	function display($tpl = null)
	{
		// Config
		$pparams = JComponentHelper::getParams('com_myjspace');

		// Tags buttons
		$e_name = JRequest::getVar('e_name', 'mjs_editable');
		$allow_tag_myjsp_iframe = $pparams->get('allow_tag_myjsp_iframe', 1);
		$allow_tag_myjsp_include = $pparams->get('allow_tag_myjsp_include', 1);
		$share_page = $pparams->get('share_page', 0);
		$language_filter = $pparams->get('language_filter', 0);
		$show_tags = version_compare(JVERSION, '3.1.4', 'ge') ? $pparams->get('show_tags', 0) : 0;

		// Pagebreak
		$eName = JRequest::getVar('eName', 'mjs_content');

		$this->assignRef('e_name', $e_name);
		$this->assignRef('eName', $eName);
		$this->assignRef('allow_tag_myjsp_iframe', $allow_tag_myjsp_iframe);
		$this->assignRef('allow_tag_myjsp_include', $allow_tag_myjsp_include);
		$this->assignRef('share_page', $share_page);
		$this->assignRef('language_filter', $language_filter);
		$this->assignRef('show_tags', $show_tags);

		parent::display($tpl);
	}
}

?>
